==> r-bioc-preprocesscore_1.22.0.orig.tar.gz: preprocessCore/inst/include/preprocessCore_summarization_stubs.h <==
void averagelog_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void averagelog(double *data, int rows, int cols, double *results, double *resultsSE);
void AverageLog(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void AverageLog_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void logaverage(double *data, int rows, int cols, double *results, double *resultsSE);
void LogAverage(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void LogAverage_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void tukeybiweight(double *data, int rows, int cols, double *results, double *resultsSE);
void tukeybiweight_no_log(double *data, int rows, int cols, double *results, double *resultsSE);
void TukeyBiweight(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void TukeyBiweight_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void TukeyBiweight_no_log_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void lm_wfit(double *x, double *y, double *w, int rows, int cols, double tol, double *out_beta, double *out_resids);
void median_polish_fit_no_copy(double *data, int rows, int cols, double *r, double *c, double *t);
void median_polish_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void median_polish_log2_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void median_polish_log2(double *data, int rows, int cols, double *results, double *resultsSE, double *residuals);
void median_polish(double *data, int rows, int cols, double *results, double *resultsSE, double *residuals);
void MedianPolish(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void MedianPolish_no_log(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void rlm_fit(double *x, double *y, int rows, int cols, double *out_beta, double *out_resids, double *out_weights, double (* PsiFn)(double, double, int), double psi_k, int max_iter,int initialized);
void rlm_wfit(double *x, double *y, double *w, int rows, int cols, double *out_beta, double *out_resids, double *out_weights, double (* PsiFn)(double, double, int), double psi_k, int max_iter,int initialized);
void rlm_fit_anova(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void rlm_wfit_anova(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void rlm_compute_se(double *X,double *Y, int n, int p, double *beta, double *resids,double *weights,double *se_estimates,double *varcov, double *residSE, int method,double (* PsiFn)(double, double, int), double psi_k);
void rlm_compute_se_anova(double *Y, int y_rows,int y_cols, double *beta, double *resids,double *weights,double *se_estimates, double *varcov, double *residSE, int method,double (* PsiFn)(double, double, int), double psi_k);
void MedianLog(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void MedianLog_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void medianlog(double *data, int rows, int cols, double *results, double *resultsSE);
void medianlog_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void LogMedian(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void LogMedian_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void logmedian(double *data, int rows, int cols, double *results, double *resultsSE);
void logmedian_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void colaverage_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void colaverage(double *data, int rows, int cols, double *results, double *resultsSE);
void ColAverage(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void ColAverage_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void colmedian_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void colmedian(double *data, int rows, int cols, double *results, double *resultsSE);
void ColMedian(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void ColMedian_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void plmr_fit(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmr_wfit(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrr_fit(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrc_fit(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrr_wfit(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrc_wfit(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void rlm_fit_anova_given_probe_effects(double *y, int y_rows, int y_cols, double *probe_effects, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double,double, int), double psi_k,int max_iter, int initialized);
void rlm_compute_se_anova_given_probe_effects(double *Y, int y_rows,int y_cols, double *probe_effects,double *beta, double *resids,double *weights,double *se_estimates, double *varcov, double *residSE, int method,double (* PsiFn)(double, double, int), double psi_k);
void rlm_wfit_anova_given_probe_effects(double *y, int y_rows, int y_cols, double *probe_effects, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double,double, int), double psi_k,int max_iter, int initialized);

==> r-bioc-preprocesscore_1.26.1.orig.tar.gz: preprocessCore/inst/include/preprocessCore_summarization_stubs.h <==
void averagelog_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void averagelog(double *data, int rows, int cols, double *results, double *resultsSE);
void AverageLog(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void AverageLog_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void logaverage(double *data, int rows, int cols, double *results, double *resultsSE);
void LogAverage(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void LogAverage_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void tukeybiweight(double *data, int rows, int cols, double *results, double *resultsSE);
void tukeybiweight_no_log(double *data, int rows, int cols, double *results, double *resultsSE);
void TukeyBiweight(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void TukeyBiweight_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void TukeyBiweight_no_log_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void lm_wfit(double *x, double *y, double *w, int rows, int cols, double tol, double *out_beta, double *out_resids);
void median_polish_fit_no_copy(double *data, size_t rows, size_t cols, double *r, double *c, double *t);
void median_polish_no_copy(double *data, size_t rows, size_t cols, double *results, double *resultsSE);
void median_polish_log2_no_copy(double *data, size_t rows, size_t cols, double *results, double *resultsSE);
void median_polish_log2(double *data, size_t rows, size_t cols, double *results, double *resultsSE, double *residuals);
void median_polish(double *data, size_t rows, size_t cols, double *results, double *resultsSE, double *residuals);
void MedianPolish(double *data, size_t rows, size_t cols, int *cur_rows, double *results, size_t nprobes, double *resultsSE);
void MedianPolish_no_log(double *data, size_t rows, size_t cols, int *cur_rows, double *results, size_t nprobes, double *resultsSE);
void rlm_fit(double *x, double *y, int rows, int cols, double *out_beta, double *out_resids, double *out_weights, double (* PsiFn)(double, double, int), double psi_k, int max_iter,int initialized);
void rlm_wfit(double *x, double *y, double *w, int rows, int cols, double *out_beta, double *out_resids, double *out_weights, double (* PsiFn)(double, double, int), double psi_k, int max_iter,int initialized);
void rlm_fit_anova(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void rlm_wfit_anova(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void rlm_compute_se(double *X,double *Y, int n, int p, double *beta, double *resids,double *weights,double *se_estimates,double *varcov, double *residSE, int method,double (* PsiFn)(double, double, int), double psi_k);
void rlm_compute_se_anova(double *Y, int y_rows,int y_cols, double *beta, double *resids,double *weights,double *se_estimates, double *varcov, double *residSE, int method,double (* PsiFn)(double, double, int), double psi_k);
void MedianLog(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void MedianLog_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void medianlog(double *data, int rows, int cols, double *results, double *resultsSE);
void medianlog_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void LogMedian(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void LogMedian_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void logmedian(double *data, int rows, int cols, double *results, double *resultsSE);
void logmedian_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void colaverage_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void colaverage(double *data, int rows, int cols, double *results, double *resultsSE);
void ColAverage(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void ColAverage_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void colmedian_no_copy(double *data, int rows, int cols, double *results, double *resultsSE);
void colmedian(double *data, int rows, int cols, double *results, double *resultsSE);
void ColMedian(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes, double *resultsSE);
void ColMedian_noSE(double *data, int rows, int cols, int *cur_rows, double *results, int nprobes);
void plmr_fit(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmr_wfit(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrr_fit(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrc_fit(double *y, int y_rows, int y_cols,double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrr_wfit(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void plmrc_wfit(double *y, int y_rows, int y_cols, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double, double, int), double psi_k,int max_iter, int initialized);
void rlm_fit_anova_given_probe_effects(double *y, int y_rows, int y_cols, double *probe_effects, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double,double, int), double psi_k,int max_iter, int initialized);
void rlm_compute_se_anova_given_probe_effects(double *Y, int y_rows,int y_cols, double *probe_effects,double *beta, double *resids,double *weights,double *se_estimates, double *varcov, double *residSE, int method,double (* PsiFn)(double, double, int), double psi_k);
void rlm_wfit_anova_given_probe_effects(double *y, int y_rows, int y_cols, double *probe_effects, double *w, double *out_beta, double *out_resids, double *out_weights,double (* PsiFn)(double,double, int), double psi_k,int max_iter, int initialized);
